@@ -16,6 +16,7 @@ class DatabaseType(enum.Enum):
 class CIType(enum.Enum):
     none = "none"
     gitlab_ci = "gitlab"
+    github = "github"
 
 
 class Database(BaseModel):
@@ -33,7 +34,7 @@ class BuilderContext(BaseModel):
     db: Optional[DatabaseType]
     db_info: Optional[Database]
     enable_redis: Optional[bool]
-    enable_ci: Optional[bool]
+    ci_type: Optional[CIType]
     enable_alembic: Optional[bool]
     enable_kube: Optional[bool]
     force: bool = False
